# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from .......schema_classes import EmailNotificationSettingsClass
from .......schema_classes import NotificationSettingsClass
from .......schema_classes import SlackNotificationSettingsClass
from .......schema_classes import TeamsNotificationSettingsClass


EmailNotificationSettings = EmailNotificationSettingsClass
NotificationSettings = NotificationSettingsClass
SlackNotificationSettings = SlackNotificationSettingsClass
TeamsNotificationSettings = TeamsNotificationSettingsClass

# fmt: on
